@@ -30,10 +30,12 @@ class PowerShap(SelectorMixin, BaseEstimator):
         include_all: bool = False,
         automatic: bool = True,
         force_convergence: bool = False,
+        limit_convergence_its: int = 0,
         limit_automatic: int = 10,
         limit_incremental_iterations: int = 10,
         limit_recursive_automatic: int = 3,
         stratify: bool = False,
+        show_progress: bool = True,
         verbose: bool = False,
         **fit_kwargs,
     ):
@@ -77,6 +79,11 @@ class PowerShap(SelectorMixin, BaseEstimator):
             Only used for automatic mode. If True, powershap will continue delete
             the found relevant features and rerun until no more relevant features are found.
             This is especially useful in high-dimensional datasets
+        limit_convergence_its: int, optional
+            The number of maximum allowed recursions when `force_convergence` is True. By
+            default 0, meaning that no limit is applied. A limit_convergence_its of 1 suggests 
+            only executing one convergence recursion 
+            after a single full automatic PowerShap execution. 
         limit_automatic: int, optional
             The number of maximum allowed iterations when `automatic` is True. By
             default None, meaning that no limit is applied.
@@ -93,6 +100,9 @@ class PowerShap(SelectorMixin, BaseEstimator):
             ..note::
                 If you want to pass a specific array as stratify (that is not `y`), you
                 can pass it as `stratify` argument to the `.fit` method.
+        show_progress: bool, optional
+            Flag indicating whether progress of the powershap iterations should be
+            shown. By default True.
         verbose: bool, optional
             Flag indicating whether verbose console output should be shown. By default
             False.
@@ -111,10 +121,12 @@ class PowerShap(SelectorMixin, BaseEstimator):
         self.include_all = include_all
         self.automatic = automatic
         self.force_convergence = force_convergence
+        self.limit_convergence_its = limit_convergence_its
         self.limit_automatic = limit_automatic
         self.limit_incremental_iterations = limit_incremental_iterations
         self.limit_recursive_automatic = limit_recursive_automatic
         self.stratify = stratify
+        self.show_progress = show_progress
         self.verbose = verbose
         self.fit_kwargs = fit_kwargs
 
@@ -222,6 +234,7 @@ class PowerShap(SelectorMixin, BaseEstimator):
                     stratify=stratify,
                     groups=groups,
                     random_seed_start=max_iterations_old,
+                    show_progress=self.show_progress,
                     **kwargs,
                 )
 
@@ -244,6 +257,7 @@ class PowerShap(SelectorMixin, BaseEstimator):
                     stratify=stratify,
                     groups=groups,
                     random_seed_start=max_iterations_old,
+                    show_progress=self.show_progress,
                     **kwargs,
                 )
 
@@ -283,19 +297,19 @@ class PowerShap(SelectorMixin, BaseEstimator):
         Parameters
         ----------
         X: array-like of shape (n_samples, n_features)
-            Training data, where ``n_samples`` is the number of samples and 
+            Training data, where ``n_samples`` is the number of samples and
             ``n_features`` is the number of features.
         y: array-like of shape (n_samples,)
             The target variable for supervised learning problems.
         stratify: array-like of shape (n_samples,), optional
             Array that will be used to perform stratified train-test splits. By default
             None.
-            Note: if None, than `y` will be used as `stratify` if the stratify flag of 
+            Note: if None, than `y` will be used as `stratify` if the stratify flag of
             the object is True.
         groups: array-like of shape (n_samples,), optional
-            Group labels for the samples used while splitting the dataset into 
+            Group labels for the samples used while splitting the dataset into
             train/test set. By default None.
-        
+
         """
         if stratify is None and self.stratify:
             # Set stratify to y, if no stratify is given and self.stratify is True
@@ -336,6 +350,7 @@ class PowerShap(SelectorMixin, BaseEstimator):
             val_size=self.val_size,
             stratify=stratify,
             groups=groups,
+            show_progress=self.show_progress,
             **kwargs,
         )
 
@@ -369,7 +384,15 @@ class PowerShap(SelectorMixin, BaseEstimator):
                     converge_df[converge_df.p_value < self.power_alpha].index.values
                 )
 
-                while len(converge_df[converge_df.p_value < self.power_alpha]) > 0:
+                # If limit_convergence_its is zero, the convergence mode does not have a limit. If not, the 
+                # While loop condition is recalculated every while loop iteration.
+                if self.limit_convergence_its > 0:
+                    current_converge_recursions = 0
+                    while_convergence_bool = current_converge_recursions < self.limit_convergence_its
+                else:
+                    while_convergence_bool = True
+
+                while((len(converge_df[converge_df.p_value < self.power_alpha]) > 0) & (while_convergence_bool)):
                     self._print("Rerunning powershap for convergence. ")
                     converge_shaps_df = self._explainer.explain(
                         X=X.drop(
@@ -380,6 +403,7 @@ class PowerShap(SelectorMixin, BaseEstimator):
                         val_size=self.val_size,
                         stratify=stratify,
                         groups=groups,
+                        show_progress=self.show_progress,
                         **kwargs,
                     )
 
@@ -415,8 +439,19 @@ class PowerShap(SelectorMixin, BaseEstimator):
                         converge_df[converge_df.p_value < self.power_alpha].index.values
                     ] = converge_df[converge_df.p_value < self.power_alpha]
 
+                    
+                    if self.limit_convergence_its > 0:
+                        current_converge_recursions += 1
+                        print(current_converge_recursions)
+                        while_convergence_bool = current_converge_recursions < self.limit_convergence_its
+
+                        if not while_convergence_bool:
+                            self._print("Convergence limit reached: Stopping convergence mode.")
+
+
                 processed_shaps_df.loc[converge_df.index.values] = converge_df
 
+
         self._print("Done!")
 
         ## Set the p-values property (used in the transform function)
